@@ -16,8 +16,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#define NL_MAJOR 1
-#define NL_MINOR 2
-#define NL_REV   7
-#define NL_DATE  "Jun 30, 2003"
-#define VERSION  "1.2.7"
+#define NL_MAJOR 2
+#define NL_MINOR 0
+#define NL_REV   5
+#define NL_DATE  "Jul 11, 2003"
+#define VERSION  "2.0.5"
